/**
 * Back 2 Browser Bytecode Translator Copyright (C) 2012 Jaroslav Tulach
 * <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. Look for COPYING file in the top folder. If not, see
 * http://opensource.org/licenses/GPL-2.0.
 */
package net.java.html.canvas;


/**
 *
 * @author antonepple
 */
public interface IGraphicsContext {

    public void arc(double centerX,
            double centerY,
            double startAngle,
            double radius,
            double endAngle,
            boolean ccw);

    public void arcTo(double x1,
            double y1,
            double x2,
            double y2,
            double r);

    public boolean isPointInPath(double x, double y);

    public void fill();

    public void stroke();

    public void beginPath();

    public void closePath();

    public void clip();

    public void moveTo(double x, double y);

    public void lineTo(double x, double y);

    public void quadraticCurveTo(double cpx, double cpy, double x, double y);

    public void bezierCurveTo(double cp1x, double cp1y, double cp2x, double cp2y, double x, double y);

    public void fillRect(double x, double y, double width, double height);

    public void strokeRect(double x, double y, double width, double height);

    public void clearRect(double x, double y, double width, double height);

    public void rect(double x, double y, double width, double height);

    public void save();

    public void restore();

    public void rotate(double angle);

    public void transform(double a, double b, double c, double d, double e, double f);

    public void setTransform(double a, double b, double c, double d, double e, double f);

    public void translate(double x, double y);

    public void scale(double x, double y);

    public void drawImage(IImage image, double x, double y);

    public void drawImage(IImage image, double x, double y, double width, double height);

    public void drawImage(IImage image, double sx, double sy, double sWidth, double sHeight, double x, double y, double width, double height);

    public void setFillStyle(String style);

    public String getFillStyle();

    public void setFillStyle(ILinearGradient style);

    public void setFillStyle(IRadialGradient style);

    public void setFillStyle(IPattern style);

    public void setStrokeStyle(String style);

    public void setStrokeStyle(ILinearGradient style);

    public void setStrokeStyle(IRadialGradient style);

    public void setStrokeStyle(IPattern style);

    public void setShadowColor(String color);

    public void setShadowBlur(double blur);

    public void setShadowOffsetX(double x);

    public void setShadowOffsetY(double y);

    public String getStrokeStyle();

    public String getShadowColor();

    public double getShadowBlur();

    public double getShadowOffsetX();

    public double getShadowOffsetY();

    public String getLineCap();

    public void setLineCap(String style);

    public String getLineJoin();

    public void setLineJoin(String style);

    public double getLineWidth();

    public void setLineWidth(double width);

    public double getMiterLimit();

    public void setMiterLimit(double limit);

    public String getFont();

    public void setFont(String font);

    public String getTextAlign();

    public void setTextAlign(String textAlign);

    public String getTextBaseline();

    public void setTextBaseline(String textbaseline);

    public void fillText(String text, double x, double y);

    public void fillText(String text, double x, double y, double maxWidth);

    public ITextMetrics measureText(String text);

    public void strokeText(String text, double x, double y);

    public void strokeText(String text, double x, double y, double maxWidth);

    public IImageData createImageData(double x, double y);

    public IImageData createImageData(IImageData imageData);

    public IImageData getImageData(double x, double y, double width, double height);

    public void putImageData(IImageData imageData, double x, double y);

    public void putImageData(IImageData imageData, double x, double y, double dirtyx, double dirtyy, double dirtywidth, double dirtyheight);

    public void setGlobalAlpha(double alpha);

    public double getGlobalAlpha();

    public void setGlobalCompositeOperation(String operation);

    public String getGlobalCompositeOperation();

    public ILinearGradient createLinearGradient(double x0, double y0, double x1, double y1);

    public IPattern createPattern(IImage image, String repeat);

    public IRadialGradient createRadialGradient(double x0, double y0, double r0, double x1, double y1, double r1);
    
    public IImage getImageForPath(String path);
}
